@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # (c) Satelligence, see LICENSE.rst.
-"""Common logging and monitoring utils
+"""Common logger and monitoring utils
 """
 import time
 
@@ -31,4 +31,3 @@ def send_metric(name, value, labels=None, timestamp=None, project=None):
         (timestamp - point.interval.end_time.seconds) * 10 ** 9)
 
     MONITORING_CLIENT.create_time_series(project_name, [series])
-
